<?php

$default_capabilities = array(
    'woocommerce' => false,
    'email' => true
);

function oribi_base64decode( $input ) {
    return base64_decode(base64_decode( $input ));
}

function oribi_register_settings() {
    global $default_capabilities;
    add_option( 'oribi_snippet' );
    add_option( 'oribi_tracking_capabilities', $default_capabilities );
    register_setting( 'oribi_options_group', 'oribi_snippet', array( 'sanitize_callback' => 'oribi_base64decode' ) );
    register_setting( 'oribi_options_group', 'oribi_tracking_capabilities' );
}
add_action( 'admin_init', 'oribi_register_settings' );

function oribi_register_options_page() {
    add_options_page( 'Oribi Analytics Settings', 'Oribi Analytics', 'manage_options', 'oribi', 'oribi_options_page_html' );
}
add_action( 'admin_menu', 'oribi_register_options_page' );

function oribi_base64encode() {
?>
<script type="text/javascript">
document.getElementById( 'submit' ).addEventListener( 'click', function () {
    var oribi_snippet = document.getElementById( 'oribi_snippet' );
    var oribi_snippet_unencoded = document.getElementById( 'oribi_snippet_unencoded' );
    oribi_snippet.value = window.btoa(window.btoa( oribi_snippet_unencoded.value ));
});
</script>
<?php
}
add_action( 'admin_footer', 'oribi_base64encode' );

function oribi_options_page_html(){
    ?>
    <div class="wrap">
        <h2><?php esc_html_e( 'Oribi Analytics for WordPress', 'oribi' ); ?></h2>

        <form method="post" action="options.php">
            <?php settings_fields( 'oribi_options_group' ); ?>

            <table class="form-table" role="presentation">
                <tbody>
                    <tr>
                        <th scope="row">
                            <label for="oribi_snippet">
                                <?php esc_html_e( 'Oribi tracking code.', 'oribi' );?>
                            </label>
                        </th>
                        <td>
                            <textarea id="oribi_snippet_unencoded" style="width: 600px; max-width: 100%; height: 200px;"><?php
                                echo get_option( 'oribi_snippet' );
                            ?></textarea>
                            <input type="hidden" id="oribi_snippet" name="oribi_snippet" />
                            <p class="description" id="home-description">
                                <?php esc_html_e( 'Don’t have your personal Oribi tracking code? ', 'oribi' );?>
                                <?php esc_html_e( 'Click','oribi' ); ?>
                                <a href="https://oribi.io/login" target="_blank" rel="noopener noreferrer">
                                    <?php esc_html_e( 'here','oribi' );?>
                                </a>.
                            </p>
                        </td>
                    </tr>

                    <?php $tracking_capabilities = Oribi_Event_Tracker::get_tracking_capabilities(); ?>
                    <tr>
                        <th scope="row">Tracking capabilities</th>
                        <td>
                            <fieldset>
                                <legend class="screen-reader-text">
                                    <span>Tracking capabilities</span>
                                </legend>
                                <label>
                                    <input type="checkbox"
                                           name="oribi_tracking_capabilities[woocommerce]"
                                           value="1" <?php checked( $tracking_capabilities['woocommerce'] ); ?> />
                                    Track WooCommerce
                                </label>
                            </fieldset>
                            <fieldset>
                                <legend class="screen-reader-text">
                                    <span>Tracking capabilities</span>
                                </legend>
                                <label>
                                    <input type="checkbox"
                                           name="oribi_tracking_capabilities[email]"
                                           value="1" <?php checked( $tracking_capabilities['email'] ); ?> />
                                    Connect Oribi’s Email Integration<br>
                                    Set up Oribi’s email integration feature to see website journeys of your top visitors and identify common patterns.
                                </label>
                            </fieldset>
                        </td>
                    </tr>
                </tbody>
            </table>

            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}
