<?php

/**
 * Plugin Name: Oribi Analytics
 * Description: You’re minutes away from automatic event tracking, user behavior analysis and marketing insights.
 * Author: Oribi
 * Author URI: https://oribi.io
 * Version: 2.1
 * Text Domain: oribi
 */

require plugin_dir_path( __FILE__ ) . '/inc/oribi-admin-settings.php';

$plugin_name = plugin_basename( __FILE__ );

function oribi_plugin_settings_link( $links ) {
    $url = esc_url( add_query_arg(
		'page',
		'oribi',
		get_admin_url() . 'admin.php'
	));

	$settings_link = "<a href='$url'>" . __( 'Settings', 'oribi' ) . '</a>';

	array_push( $links, $settings_link );
	return $links;
}
add_filter( "plugin_action_links_{$plugin_name}", 'oribi_plugin_settings_link' );


function oribi_get_snippet() {
	$snippet = '';

	if ( ! empty( get_option( 'oribi_snippet' ) ) ) {
        $snippet = get_option( 'oribi_snippet' );
	}

	return $snippet;
}


function oribi_insert_snippet() {
	echo oribi_get_snippet();
}
add_action( 'wp_head', 'oribi_insert_snippet' );

register_activation_hook( __FILE__, 'oribi_plugin_activate' );
function oribi_plugin_activate() {
    update_option( 'oribi_tracking_capabilities', Oribi_Event_Tracker::get_tracking_capabilities() );
}

class Oribi_Event_Tracker {
    public static $default_tracking_capabilities = array(
        'woocommerce' => false,
        'email' => true
    );

    public static function init() {
        $tracking_capabilities = self::get_tracking_capabilities();

        if ( isset( $tracking_capabilities['woocommerce'] ) && (bool)$tracking_capabilities['woocommerce'] ) {
            add_action( 'woocommerce_thankyou', array( self::class, 'oribi_track_woocommerce_purchase' ) );
        }

        if ( isset( $tracking_capabilities['email'] ) && (bool)$tracking_capabilities['email'] ) {
            add_action( 'wp_head', array( self::class, 'oribi_track_users_email' ) );
        }
    }

    public static function get_tracking_capabilities() {
        $tracking_capabilities = get_option( 'oribi_tracking_capabilities' );
        $default_unchecked = array(
            'woocommerce' => false,
            'email' => false
        );
        $tracking_capabilities =
            is_array( $tracking_capabilities )
                ? array_replace( $default_unchecked, $tracking_capabilities )
                : $default_unchecked;
        return array_replace( self::$default_tracking_capabilities, $tracking_capabilities );
    }

    public static function oribi_track_users_email() {
        $user_email = null;
        if ( is_user_logged_in() ) {
            $user_email = wp_get_current_user()->user_email;
        }
        if ( isset( $user_email ) ) {
            ?>
            <script>
                document.addEventListener('DOMContentLoaded', function() {
                    ORIBI.api('setUserEmail', '<?php echo $user_email ?>');
                });
            </script>
            <?php
        }
    }

    public static function oribi_track_woocommerce_purchase( $order_id ) {
        $order    = wc_get_order( $order_id );
        $items    = $order->get_items();
        $products = array();

        $user_email = $order->get_billing_email();
        if ( !isset($user_email) && is_user_logged_in() ) {
            $user_email = wp_get_current_user()->user_email;
        }

        foreach( $items as $item ) {
            $terms = get_the_terms ( $item->get_product_id(), 'product_cat' );

            $product = $item->get_product();
            $quantity = (int)$item->get_quantity();
            $price = (float)$item->get_subtotal() / $quantity;
            $productRegularPrice = (float)$product->get_regular_price();
            $productActivePrice = (float)$product->get_price();
            if ($productRegularPrice >= $productActivePrice) {
                $discountPrice = $productRegularPrice - $productActivePrice;
            } else {
                $discountPrice = $productRegularPrice - $price;
            }
            $discountPrice = $discountPrice > 0 ? $discountPrice : 0;

            $product = array(
                'id'            => $item->get_product_id(),
                'name'          => $item->get_name(),
                'price'         => $price,
                'taxPrice'      => (float)$item->get_subtotal_tax() / $quantity,
                'discountPrice' => $discountPrice,
                'quantity'      => $quantity,
                'categories'    => array(),
            );

            foreach( $terms as $term ){
                $product['categories'][] = $term->name;
            }

            $products[] = $product;
        }

        $data = array(
            'orderId'       => $order_id,
            'currency'      => $order->get_currency(),
            'totalPrice'    => (float)$order->get_total(),
            'taxPrice'      => (float)$order->get_total_tax(),
            'shippingPrice' => (float)$order->calculate_shipping(),
            'discountPrice' => (float)$order->get_total_discount(),
            'products'      => $products,
            'source'        => 'WooCommerce',
        );

        $customer_id = $order->get_customer_id();
        if ( $customer_id > 0 ) {
            $customer = new WC_Customer( $customer_id );
            $data['isFirstPurchase'] = $customer->get_order_count() === 1;
        }
        $data = json_encode($data);
        ?>
        <script>
            document.addEventListener('DOMContentLoaded', function() {
                <?php if( isset( $user_email ) && (bool)self::get_tracking_capabilities()['email'] ): ?>
                ORIBI.api('setUserEmail', '<?php echo $user_email ?>');
                <?php endif; ?>
                ORIBI.api('trackIntegratePurchase', <?php echo $data ?>);
            });
        </script>
        <?php
    }
}

Oribi_Event_Tracker::init();
